# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/featurestore/api/v1/DashboardApi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/h2o/featurestore/api/v1/DashboardApi.proto\x12\x1a\x61i.h2o.featurestore.api.v1\"a\n\x11\x44\x61shboardResponse\x12\x16\n\x0eproject_number\x18\x01 \x01(\x04\x12\x1b\n\x13\x66\x65\x61ture_sets_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x66\x65\x61tures_number\x18\x03 \x01(\x04\x42\x13\x42\x11\x44\x61shboardApiProtob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.featurestore.api.v1.DashboardApi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\021DashboardApiProto'
  _globals['_DASHBOARDRESPONSE']._serialized_start=77
  _globals['_DASHBOARDRESPONSE']._serialized_end=174
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/featurestore/api/v1/OnlineApi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.h2o.featurestore.api.v1 import FeatureSetProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/h2o/featurestore/api/v1/OnlineApi.proto\x12\x1a\x61i.h2o.featurestore.api.v1\x1a\x33\x61i/h2o/featurestore/api/v1/FeatureSetProtoApi.proto\"b\n\x15OnlineRetrieveRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x0b\n\x03key\x18\x02 \x03(\t\"%\n\x16OnlineRetrieveResponse\x12\x0b\n\x03row\x18\x01 \x01(\t\"a\n\x13OnlineIngestRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x0c\n\x04rows\x18\x02 \x03(\tB\x10\x42\x0eOnlineApiProtob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.featurestore.api.v1.OnlineApi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\016OnlineApiProto'
  _globals['_ONLINERETRIEVEREQUEST']._serialized_start=127
  _globals['_ONLINERETRIEVEREQUEST']._serialized_end=225
  _globals['_ONLINERETRIEVERESPONSE']._serialized_start=227
  _globals['_ONLINERETRIEVERESPONSE']._serialized_end=264
  _globals['_ONLINEINGESTREQUEST']._serialized_start=266
  _globals['_ONLINEINGESTREQUEST']._serialized_end=363
# @@protoc_insertion_point(module_scope)
